==> flink-1.12.7-src.tgz: flink-1.12.7/flink-core/src/test/java/org/apache/flink/api/common/typeutils/base/BigIntSerializerTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.flink.api.common.typeutils.base;

import org.apache.flink.api.common.typeutils.SerializerTestBase;
import org.apache.flink.api.common.typeutils.TypeSerializer;

import java.math.BigInteger;
import java.util.Random;

/** A test for the {@link BigIntSerializer}. */
public class BigIntSerializerTest extends SerializerTestBase<BigInteger> {

    @Override
    protected TypeSerializer<BigInteger> createSerializer() {
        return new BigIntSerializer();
    }

    @Override
    protected int getLength() {
        return -1;
    }

    @Override
    protected Class<BigInteger> getTypeClass() {
        return BigInteger.class;
    }

    @Override
    protected BigInteger[] getTestData() {
        Random rnd = new Random(874597969123412341L);

        return new BigInteger[] {
            BigInteger.ZERO,
            BigInteger.ONE,
            BigInteger.TEN,
            new BigInteger(1000, rnd),
            new BigInteger("8745979691234123413478523984729447"),
            BigInteger.valueOf(-1),
            BigInteger.valueOf(-10000)
        };
    }
}

==> flink-1.20.3-src.tgz: flink-1.20.3/flink-core/src/test/java/org/apache/flink/api/common/typeutils/base/BigIntSerializerTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.flink.api.common.typeutils.base;

import org.apache.flink.api.common.typeutils.SerializerTestBase;
import org.apache.flink.api.common.typeutils.TypeSerializer;

import java.math.BigInteger;
import java.util.Random;

/** A test for the {@link BigIntSerializer}. */
class BigIntSerializerTest extends SerializerTestBase<BigInteger> {

    @Override
    protected TypeSerializer<BigInteger> createSerializer() {
        return new BigIntSerializer();
    }

    @Override
    protected int getLength() {
        return -1;
    }

    @Override
    protected Class<BigInteger> getTypeClass() {
        return BigInteger.class;
    }

    @Override
    protected BigInteger[] getTestData() {
        Random rnd = new Random(874597969123412341L);

        return new BigInteger[] {
            BigInteger.ZERO,
            BigInteger.ONE,
            BigInteger.TEN,
            new BigInteger(1000, rnd),
            new BigInteger("8745979691234123413478523984729447"),
            BigInteger.valueOf(-1),
            BigInteger.valueOf(-10000)
        };
    }
}
